@@ -19,6 +19,7 @@ from __future__ import annotations
 
 import os
 from contextlib import closing
+from functools import wraps
 from io import StringIO
 from pathlib import Path
 from typing import Any, Callable, Iterable, Mapping
@@ -41,6 +42,34 @@ def _try_to_boolean(value: Any):
     return value
 
 
+def _ensure_prefixes(conn_type):
+    """
+    Remove when provider min airflow version >= 2.5.0 since this is handled by
+    provider manager from that version.
+    """
+
+    def dec(func):
+        @wraps(func)
+        def inner():
+            field_behaviors = func()
+            conn_attrs = {"host", "schema", "login", "password", "port", "extra"}
+
+            def _ensure_prefix(field):
+                if field not in conn_attrs and not field.startswith("extra__"):
+                    return f"extra__{conn_type}__{field}"
+                else:
+                    return field
+
+            if "placeholders" in field_behaviors:
+                placeholders = field_behaviors["placeholders"]
+                field_behaviors["placeholders"] = {_ensure_prefix(k): v for k, v in placeholders.items()}
+            return field_behaviors
+
+        return inner
+
+    return dec
+
+
 class SnowflakeHook(DbApiHook):
     """
     A client to interact with Snowflake.
@@ -78,11 +107,12 @@ class SnowflakeHook(DbApiHook):
         :ref:`howto/operator:SnowflakeOperator`
     """
 
-    conn_name_attr = 'snowflake_conn_id'
-    default_conn_name = 'snowflake_default'
-    conn_type = 'snowflake'
-    hook_name = 'Snowflake'
+    conn_name_attr = "snowflake_conn_id"
+    default_conn_name = "snowflake_default"
+    conn_type = "snowflake"
+    hook_name = "Snowflake"
     supports_autocommit = True
+    _test_connection_sql = "select 1"
 
     @staticmethod
     def get_connection_form_widgets() -> dict[str, Any]:
@@ -92,34 +122,31 @@ class SnowflakeHook(DbApiHook):
         from wtforms import BooleanField, StringField
 
         return {
-            "extra__snowflake__account": StringField(lazy_gettext('Account'), widget=BS3TextFieldWidget()),
-            "extra__snowflake__warehouse": StringField(
-                lazy_gettext('Warehouse'), widget=BS3TextFieldWidget()
+            "account": StringField(lazy_gettext("Account"), widget=BS3TextFieldWidget()),
+            "warehouse": StringField(lazy_gettext("Warehouse"), widget=BS3TextFieldWidget()),
+            "database": StringField(lazy_gettext("Database"), widget=BS3TextFieldWidget()),
+            "region": StringField(lazy_gettext("Region"), widget=BS3TextFieldWidget()),
+            "role": StringField(lazy_gettext("Role"), widget=BS3TextFieldWidget()),
+            "private_key_file": StringField(lazy_gettext("Private key (Path)"), widget=BS3TextFieldWidget()),
+            "private_key_content": StringField(
+                lazy_gettext("Private key (Text)"), widget=BS3TextAreaFieldWidget()
             ),
-            "extra__snowflake__database": StringField(lazy_gettext('Database'), widget=BS3TextFieldWidget()),
-            "extra__snowflake__region": StringField(lazy_gettext('Region'), widget=BS3TextFieldWidget()),
-            "extra__snowflake__role": StringField(lazy_gettext('Role'), widget=BS3TextFieldWidget()),
-            "extra__snowflake__private_key_file": StringField(
-                lazy_gettext('Private key (Path)'), widget=BS3TextFieldWidget()
-            ),
-            "extra__snowflake__private_key_content": StringField(
-                lazy_gettext('Private key (Text)'), widget=BS3TextAreaFieldWidget()
-            ),
-            "extra__snowflake__insecure_mode": BooleanField(
-                label=lazy_gettext('Insecure mode'), description="Turns off OCSP certificate checks"
+            "insecure_mode": BooleanField(
+                label=lazy_gettext("Insecure mode"), description="Turns off OCSP certificate checks"
             ),
         }
 
     @staticmethod
+    @_ensure_prefixes(conn_type="snowflake")
     def get_ui_field_behaviour() -> dict[str, Any]:
         """Returns custom field behaviour"""
         import json
 
         return {
-            "hidden_fields": ['port'],
+            "hidden_fields": ["port"],
             "relabeling": {},
             "placeholders": {
-                'extra': json.dumps(
+                "extra": json.dumps(
                     {
                         "authenticator": "snowflake oauth",
                         "private_key_file": "private key",
@@ -127,17 +154,17 @@ class SnowflakeHook(DbApiHook):
                     },
                     indent=1,
                 ),
-                'schema': 'snowflake schema',
-                'login': 'snowflake username',
-                'password': 'snowflake password',
-                'extra__snowflake__account': 'snowflake account name',
-                'extra__snowflake__warehouse': 'snowflake warehouse name',
-                'extra__snowflake__database': 'snowflake db name',
-                'extra__snowflake__region': 'snowflake hosted region',
-                'extra__snowflake__role': 'snowflake role',
-                'extra__snowflake__private_key_file': 'Path of snowflake private key (PEM Format)',
-                'extra__snowflake__private_key_content': 'Content to snowflake private key (PEM format)',
-                'extra__snowflake__insecure_mode': 'insecure mode',
+                "schema": "snowflake schema",
+                "login": "snowflake username",
+                "password": "snowflake password",
+                "account": "snowflake account name",
+                "warehouse": "snowflake warehouse name",
+                "database": "snowflake db name",
+                "region": "snowflake hosted region",
+                "role": "snowflake role",
+                "private_key_file": "Path of snowflake private key (PEM Format)",
+                "private_key_content": "Content to snowflake private key (PEM format)",
+                "insecure_mode": "insecure mode",
             },
         }
 
@@ -153,35 +180,48 @@ class SnowflakeHook(DbApiHook):
         self.session_parameters = kwargs.pop("session_parameters", None)
         self.query_ids: list[str] = []
 
+    def _get_field(self, extra_dict, field_name):
+        backcompat_prefix = "extra__snowflake__"
+        backcompat_key = f"{backcompat_prefix}{field_name}"
+        if field_name.startswith("extra__"):
+            raise ValueError(
+                f"Got prefixed name {field_name}; please remove the '{backcompat_prefix}' prefix "
+                f"when using this method."
+            )
+        if field_name in extra_dict:
+            import warnings
+
+            if backcompat_key in extra_dict:
+                warnings.warn(
+                    f"Conflicting params `{field_name}` and `{backcompat_key}` found in extras. "
+                    f"Using value for `{field_name}`.  Please ensure this is the correct "
+                    f"value and remove the backcompat key `{backcompat_key}`."
+                )
+            return extra_dict[field_name] or None
+        return extra_dict.get(backcompat_key) or None
+
     def _get_conn_params(self) -> dict[str, str | None]:
         """
         One method to fetch connection params as a dict
         used in get_uri() and get_connection()
         """
         conn = self.get_connection(self.snowflake_conn_id)  # type: ignore[attr-defined]
-        account = conn.extra_dejson.get('extra__snowflake__account', '') or conn.extra_dejson.get(
-            'account', ''
-        )
-        warehouse = conn.extra_dejson.get('extra__snowflake__warehouse', '') or conn.extra_dejson.get(
-            'warehouse', ''
-        )
-        database = conn.extra_dejson.get('extra__snowflake__database', '') or conn.extra_dejson.get(
-            'database', ''
-        )
-        region = conn.extra_dejson.get('extra__snowflake__region', '') or conn.extra_dejson.get('region', '')
-        role = conn.extra_dejson.get('extra__snowflake__role', '') or conn.extra_dejson.get('role', '')
-        schema = conn.schema or ''
-        authenticator = conn.extra_dejson.get('authenticator', 'snowflake')
-        session_parameters = conn.extra_dejson.get('session_parameters')
-        insecure_mode = _try_to_boolean(
-            conn.extra_dejson.get(
-                'extra__snowflake__insecure_mode', conn.extra_dejson.get('insecure_mode', None)
-            )
-        )
+        extra_dict = conn.extra_dejson
+        account = self._get_field(extra_dict, "account") or ""
+        warehouse = self._get_field(extra_dict, "warehouse") or ""
+        database = self._get_field(extra_dict, "database") or ""
+        region = self._get_field(extra_dict, "region") or ""
+        role = self._get_field(extra_dict, "role") or ""
+        insecure_mode = _try_to_boolean(self._get_field(extra_dict, "insecure_mode"))
+        schema = conn.schema or ""
+
+        # authenticator and session_parameters never supported long name so we don't use _get_field
+        authenticator = extra_dict.get("authenticator", "snowflake")
+        session_parameters = extra_dict.get("session_parameters")
 
         conn_config = {
             "user": conn.login,
-            "password": conn.password or '',
+            "password": conn.password or "",
             "schema": self.schema or schema,
             "database": self.database or database,
             "account": self.account or account,
@@ -194,7 +234,7 @@ class SnowflakeHook(DbApiHook):
             "application": os.environ.get("AIRFLOW_SNOWFLAKE_PARTNER", "AIRFLOW"),
         }
         if insecure_mode:
-            conn_config['insecure_mode'] = insecure_mode
+            conn_config["insecure_mode"] = insecure_mode
 
         # If private_key_file is specified in the extra json, load the contents of the file as a private key.
         # If private_key_content is specified in the extra json, use it as a private key.
@@ -202,12 +242,8 @@ class SnowflakeHook(DbApiHook):
         # The connection password then becomes the passphrase for the private key.
         # If your private key is not encrypted (not recommended), then leave the password empty.
 
-        private_key_file = conn.extra_dejson.get(
-            'extra__snowflake__private_key_file'
-        ) or conn.extra_dejson.get('private_key_file')
-        private_key_content = conn.extra_dejson.get(
-            'extra__snowflake__private_key_content'
-        ) or conn.extra_dejson.get('private_key_content')
+        private_key_file = self._get_field(extra_dict, "private_key_file")
+        private_key_content = self._get_field(extra_dict, "private_key_content")
 
         private_key_pem = None
         if private_key_content and private_key_file:
@@ -235,8 +271,8 @@ class SnowflakeHook(DbApiHook):
                 encryption_algorithm=serialization.NoEncryption(),
             )
 
-            conn_config['private_key'] = pkb
-            conn_config.pop('password', None)
+            conn_config["private_key"] = pkb
+            conn_config.pop("password", None)
 
         return conn_config
 
@@ -250,7 +286,7 @@ class SnowflakeHook(DbApiHook):
             **{
                 k: v
                 for k, v in conn_params.items()
-                if v and k not in ['session_parameters', 'insecure_mode', 'private_key']
+                if v and k not in ["session_parameters", "insecure_mode", "private_key"]
             }
         )
 
@@ -269,13 +305,13 @@ class SnowflakeHook(DbApiHook):
         """
         engine_kwargs = engine_kwargs or {}
         conn_params = self._get_conn_params()
-        if 'insecure_mode' in conn_params:
-            engine_kwargs.setdefault('connect_args', dict())
-            engine_kwargs['connect_args']['insecure_mode'] = True
-        for key in ['session_parameters', 'private_key']:
+        if "insecure_mode" in conn_params:
+            engine_kwargs.setdefault("connect_args", dict())
+            engine_kwargs["connect_args"]["insecure_mode"] = True
+        for key in ["session_parameters", "private_key"]:
             if conn_params.get(key):
-                engine_kwargs.setdefault('connect_args', dict())
-                engine_kwargs['connect_args'][key] = conn_params[key]
+                engine_kwargs.setdefault("connect_args", dict())
+                engine_kwargs["connect_args"][key] = conn_params[key]
         return create_engine(self._conn_params_to_sqlalchemy_uri(conn_params), **engine_kwargs)
 
     def set_autocommit(self, conn, autocommit: Any) -> None:
@@ -283,7 +319,7 @@ class SnowflakeHook(DbApiHook):
         conn.autocommit_mode = autocommit
 
     def get_autocommit(self, conn):
-        return getattr(conn, 'autocommit_mode', False)
+        return getattr(conn, "autocommit_mode", False)
 
     def run(
         self,
@@ -355,11 +391,3 @@ class SnowflakeHook(DbApiHook):
             return results[-1]
         else:
             return results
-
-    def test_connection(self):
-        """Test the Snowflake connection by running a simple query."""
-        try:
-            self.run(sql="select 1")
-        except Exception as e:
-            return False, str(e)
-        return True, "Connection successfully tested"
